@@ -3,7 +3,7 @@ import logging
 
 
 def setup_module(thismodulebypytest):
-    logging.debug('setup_module-')
+    logging.debug("setup_module-")
 
 
 def session_00000():
@@ -21,12 +21,12 @@ def session_00001():
 
 
 def test_1(capsys):
-    logging.debug('test_1-')
+    logging.debug("test_1-")
 
 
 def test_2(capsys):
-    logging.debug('test_2-')
-    assert False    # fail the test case, won't be executed since -x fail above
+    logging.debug("test_2-")
+    assert False  # fail the test case, won't be executed since -x fail above
 
 
 def session_00002():
@@ -37,8 +37,8 @@ def session_00002():
 
 
 def test_3(capsys):
-    logging.debug('test_3-')
+    logging.debug("test_3-")
 
 
 def teardown_module():
-    logging.debug('teardown_module-')
+    logging.debug("teardown_module-")
