@@ -9,28 +9,30 @@ from phmdoctest.functions import _phm_compare_exact
 def _phm_setup_teardown(managenamespace):
     # setup code line 9.
     import math
+
     mylist = [1, 2, 3]
     a, b = 10, 11
+
     def doubler(x):
         return x * 2
 
-    managenamespace(operation='update', additions=locals())
+    managenamespace(operation="update", additions=locals())
     yield
-    # teardown code line 56.
+    # teardown code line 58.
     mylist.clear()
-    assert not mylist, 'mylist was not emptied'
+    assert not mylist, "mylist was not emptied"
 
-    managenamespace(operation='clear')
+    managenamespace(operation="clear")
 
 
 pytestmark = pytest.mark.usefixtures("_phm_setup_teardown")
 
 
-def test_code_18_output_25(capsys):
-    print('math.pi=', round(math.pi, 3))
+def test_code_20_output_27(capsys):
+    print("math.pi=", round(math.pi, 3))
     print(mylist)
     print(a, b)
-    print('doubler(16)=', doubler(16))
+    print("doubler(16)=", doubler(16))
 
     _phm_expected_str = """\
 math.pi= 3.142
@@ -41,7 +43,7 @@ doubler(16)= 32
     _phm_compare_exact(a=_phm_expected_str, b=capsys.readouterr().out)
 
 
-def test_code_35_output_40(capsys):
+def test_code_37_output_42(capsys):
     mylist.append(4)
     print(mylist)
 
@@ -51,7 +53,7 @@ def test_code_35_output_40(capsys):
     _phm_compare_exact(a=_phm_expected_str, b=capsys.readouterr().out)
 
 
-def test_code_45_output_49(capsys):
+def test_code_47_output_51(capsys):
     print(mylist == [1, 2, 3, 4])
 
     _phm_expected_str = """\
