@@ -51,7 +51,7 @@ def make_label_unique(label: str, line_num: int, used: Set[str]) -> str:
 
 
 def get_skipif_minor_number(block: FencedBlock) -> int:
-    """ "Get block's first skipif minor numeric value, if it exists."""
+    """Get block's first skipif minor numeric value, if it exists."""
     # Return zero if there is no such directive.
     minor_number = 0
     for directive in block.directives:
@@ -59,13 +59,14 @@ def get_skipif_minor_number(block: FencedBlock) -> int:
             value = directive.value
             try:
                 minor_number = int(value, 10)
-                assert minor_number > 0
-            except (AssertionError, ValueError):
+                if minor_number < 0:
+                    raise ValueError("phmdoctest- must be >= 0")
+            except ValueError:
                 lines = [
                     Marker.PYTEST_SKIPIF.value + "{}-->".format(value),
                     (
                         "at markdown file line {} ".format(directive.line)
-                        + "must be a decimal number and greater than zero."
+                        + "must be a decimal number and >= zero."
                     ),
                 ]
                 message = "\n".join(lines)
@@ -137,7 +138,7 @@ def setup_and_teardown_fixture(
 
     if setup_block:
         comment = "# setup code line {}.\n".format(setup_block.line)
-        code, _ = apply_inline_commands((setup_block.contents))
+        code, _ = apply_inline_commands(setup_block.contents)
         full_code = comment + code
         indented_code = textwrap.indent(full_code, "    ")
         src = src.replace("    # <setup code here>\n", indented_code, 1)
@@ -226,10 +227,9 @@ def test_case(block: FencedBlock, used_names: Set[str]) -> str:
     if not function_name:
         code_identifier = "test_code_" + str(block.line)
         output_identifier = ""
-        if block.output:
+        if block.output and block.output.role != Role.SKIP_OUTPUT:
             output_identifier = "_output_" + str(block.output.line)
         function_name = code_identifier + output_identifier
-    assert function_name.isidentifier(), "must be a valid python identifier"
     code, num_commented_out_sections = apply_inline_commands(block.contents)
     if num_commented_out_sections:
         function_name += "_{}".format(num_commented_out_sections)
@@ -311,13 +311,15 @@ def build_test_cases(args: Args, blocks: List[FencedBlock]) -> str:
     # Sequence number to order sessions.
     session_counter = itertools.count(1)
 
-    # collect the generated code in a single string
-    # repr escapes back slashes from win filesystem paths
-    # so it can be part of the generated test module docstring.
-    quoted_markdown_path = repr(click.format_filename(args.markdown_file))
-    markdown_path = quoted_markdown_path[1:-1]
-    docstring_text = "pytest file built from {}".format(markdown_path)
-    generated = StringIO()
+    # create the generated test file docstring.
+    built_from = args.built_from
+    if not built_from:
+        # repr escapes back slashes from win filesystem paths
+        # so it can be part of the generated test module docstring.
+        quoted_path = repr(click.format_filename(args.markdown_file))
+        built_from = quoted_path[1:-1]
+    docstring_text = "pytest file built from {}".format(built_from)
+    generated = StringIO()  # collect the generated code in a single string
     generated.write('"""' + docstring_text + '"""\n')
 
     setup_block = get_block_with_role(blocks, Role.SETUP)
