@@ -1,32 +1,26 @@
 """Tests for managenamespace fixture in fixture.py."""
+import pprint
 import sys
 
 import pytest
 
 from phmdoctest.fixture import managenamespace
-import verify
 
 
 # Note:
-# The two check_integrity() assertions listed here.
-# 1.   assert original_attributes.isdisjoint(namespace_names), no_originals
-# 2.   assert current_attributes == original_attributes.union(
-#          namespace_names), no_extras
+# The two check_integrity() exceptions listed here.
+# 1.   raise AttributeError(no_originals)
+# 2.   raise AttributeError(no_extras)
+#
 # Require manual testing.
-# Edit fixture.py and run pytest on this file.
+# Edit fixture.py and run pytest on this file to inject the error.
 #
-# 1. namespace_names.add('verify')    # add this line to fail the 1st assertion
-#    assert original_attributes.isdisjoint(namespace_names), no_originals
-#    assert current_attributes == original_attributes.union(
-#        namespace_names), no_extras
+# 1. namespace_names.add('verify')    # add this line above the 1st raise.
 #
-# 2. namespace_names.add('bogus')    # add this line to fail the 2nd assertion
-#    assert original_attributes.isdisjoint(namespace_names), no_originals
-#    assert current_attributes == original_attributes.union(
-#        namespace_names), no_extras
+# 2. namespace_names.add('bogus')    # add this line above the 2nd raise.
 
 
-def test_managenamespace_outfile():
+def test_managenamespace_outfile(example_tester):
     """Show that managenamespace.md generates test_managenamespace.py."""
 
     # Generate an outfile from tests/managenamespace.md and
@@ -40,7 +34,7 @@ def test_managenamespace_outfile():
     # and import sys in the example code is needed to test
     # that line of code.
     command = "phmdoctest tests/managenamespace.md --outfile discarded.py"
-    _ = verify.one_example(
+    _ = example_tester(
         command, want_file_name="tests/test_managenamespace.py", pytest_options=None
     )
 
@@ -83,17 +77,20 @@ def test_update_item_removals(managenamespace):
 
 def test_check_attribute_name_asserts(managenamespace):
     """Update asserts if an item is in the original module namespace."""
-    items = {"verify": None}
-    with pytest.raises(AssertionError) as exc_info:
+    # This test requires import pprint at the top of this file so that
+    # the update operation below will attempt to replace the pprint
+    # name in the module.
+    items = {"pprint": None}
+    with pytest.raises(AttributeError) as exc_info:
         managenamespace(operation="update", additions=items)
-    want = "Not allowed to replace module level name verify because"
+    want = "phmdoctest- Not allowed to replace module level name pprint because"
     assert want in str(exc_info.value)
 
 
 def test_illegal_operation(managenamespace):
     """Update asserts if operation in not 'update', 'copy', or 'clear'."""
     items = {"E": None, "F": None}
-    with pytest.raises(AssertionError) as exc_info:
+    with pytest.raises(ValueError) as exc_info:
         managenamespace(operation="bogus", additions=items)
-    want = 'operation="bogus" is not allowed'
+    want = 'phmdoctest- operation="bogus" is not allowed'
     assert want in str(exc_info.value)
