@@ -1,9 +1,10 @@
 """Second group of pytest test cases for phmdoctest."""
+from pathlib import Path
+
 import phmdoctest
 import phmdoctest.cases
 import phmdoctest.main
 import phmdoctest.simulator
-import verify
 
 
 def test_skip_first():
@@ -18,7 +19,7 @@ def test_skip_first():
     assert simulator_status.runner_status.exit_code == 0
     assert simulator_status.pytest_exit_code == 0
     stdout = simulator_status.runner_status.stdout
-    assert 'py3         9  skip-code     "FIRST"' in stdout
+    assert 'python       9  skip-code     "FIRST"' in stdout
     assert "FIRST         9" in stdout
 
 
@@ -31,7 +32,7 @@ def test_skip_second():
     assert simulator_status.runner_status.exit_code == 0
     assert simulator_status.pytest_exit_code == 0
     stdout = simulator_status.runner_status.stdout
-    assert 'py3        20  skip-code    "SECOND"' in stdout
+    assert 'python      20  skip-code    "SECOND"' in stdout
     assert "SECOND        20" in stdout
 
 
@@ -47,7 +48,7 @@ def test_skip_first_session():
     assert simulator_status.runner_status.exit_code == 0
     assert simulator_status.pytest_exit_code == 0
     stdout = simulator_status.runner_status.stdout
-    assert 'pycon        3  skip-session  "FIRST"' in stdout
+    assert 'py          3  skip-session  "FIRST"' in stdout
     assert "FIRST         3" in stdout
 
 
@@ -63,7 +64,7 @@ def test_skip_second_session():
     assert simulator_status.runner_status.exit_code == 0
     assert simulator_status.pytest_exit_code == 0
     stdout = simulator_status.runner_status.stdout
-    assert 'py           8  skip-session  "SECOND"' in stdout
+    assert 'py          8  skip-session  "SECOND"' in stdout
     assert "SECOND        8" in stdout
 
 
@@ -94,7 +95,7 @@ def test_skip_second_when_more_than_one():
     assert simulator_status.runner_status.exit_code == 0
     assert simulator_status.pytest_exit_code == 0
     stdout = simulator_status.runner_status.stdout
-    assert 'py3        20  skip-code    "SECOND"' in stdout
+    assert 'python      20  skip-code    "SECOND"' in stdout
     assert "SECOND        20" in stdout
 
 
@@ -110,8 +111,8 @@ def test_skip_code_that_has_no_output_block():
     assert simulator_status.runner_status.exit_code == 0
     assert simulator_status.pytest_exit_code == 0
     stdout = simulator_status.runner_status.stdout
-    assert 'py3        20  skip-code    "SECOND"' in stdout
-    assert 'py3        37  skip-code    "while a < 1000:"' in stdout
+    assert 'python      20  skip-code    "SECOND"' in stdout
+    assert 'python      37  skip-code    "while a < 1000:"' in stdout
     assert "SECOND           20" in stdout
     assert "while a < 1000:  37" in stdout
 
@@ -123,7 +124,7 @@ def test_skip_matches_start_of_contents():
         '  --skip="words =" --report --outfile discarded.py'
     )
     simulator_status = phmdoctest.simulator.run_and_pytest(
-        well_formed_command=command, pytest_options=["--doctest-modules", "-vv"]
+        well_formed_command=command, pytest_options=["--doctest-modules", "-v"]
     )
     assert simulator_status.runner_status.exit_code == 0
     assert simulator_status.pytest_exit_code == 0
@@ -138,23 +139,23 @@ def test_multiple_skips_report():
         well_formed_command=command, pytest_options=None
     )
     assert simulator_status.runner_status.exit_code == 0
+    assert simulator_status.pytest_exit_code is None
     stdout = simulator_status.runner_status.stdout
     assert '                            "len"' in stdout
     assert "len           44" in stdout
 
 
-def test_one_skip_many_matches():
+def test_one_skip_many_matches(checker):
     """Every block matches the skip pattern presenting multi-line report."""
     command = "phmdoctest tests/twentysix_session_blocks.md" ' --skip=">>>" --report'
     simulator_status = phmdoctest.simulator.run_and_pytest(
         well_formed_command=command, pytest_options=None
     )
     assert simulator_status.runner_status.exit_code == 0
+    assert simulator_status.pytest_exit_code is None
     stdout = simulator_status.runner_status.stdout
-
-    with open("tests/twentysix_report.txt", "r", encoding="utf-8") as f:
-        want = f.read()
-    verify.a_and_b_are_the_same(want, stdout)
+    want = Path("tests/twentysix_report.txt").read_text(encoding="utf-8")
+    checker(want, stdout)
 
 
 def test_no_output_blocks():
@@ -164,6 +165,7 @@ def test_no_output_blocks():
         well_formed_command=command, pytest_options=None
     )
     assert simulator_status.runner_status.exit_code == 0
+    assert simulator_status.pytest_exit_code is None
     assert simulator_status.outfile
     assert "phm_compare_exact" not in simulator_status.outfile
     assert "expected_str" not in simulator_status.outfile
