@@ -1,14 +1,15 @@
 """pytest test cases for examples in fenced code blocks in README.md."""
 
+import inspect
+from pathlib import Path
 import re
+import textwrap
 
 import phmdoctest.main
 import phmdoctest.direct
 import phmdoctest.inline
 import phmdoctest.simulator
 import phmdoctest.tool
-import verify
-import quick_links
 
 # Caution:
 # This test file is run by pytest.
@@ -20,41 +21,86 @@ import quick_links
 labeled = phmdoctest.tool.FCBChooser("README.md")
 
 
-def test_directive_example_raw():
+def example_code_checker(callable_function, example_string, checker_function):
+    """Check that the body of the function matches the string."""
+    want1 = inspect.getsource(callable_function)
+    got = textwrap.indent(example_string, "    ")
+    # Drop the def function_name line.
+    newline_index = want1.find("\n")
+    assert newline_index > -1, "must have a newline"
+    assert len(want1) > newline_index + 2, "must have more after newline"
+    want2 = want1[newline_index + 1 :]
+    checker_function(want2, got)
+
+
+def test_directive_example_raw(checker):
     """README raw markdown is same as the disk file."""
     want = labeled.contents(label="directive-example-raw")
-    with open("tests/one_mark_skip.md", "r", encoding="utf-8") as fp:
-        got = fp.read()
-        verify.a_and_b_are_the_same(want, got)
+    got = Path("tests/one_mark_skip.md").read_text(encoding="utf-8")
+    checker(want, got)
 
 
-def test_directive_example():
+def test_directive_example(example_tester, checker):
     """Make sure generated --outfile is as expected; Run pytest.
 
     Check the --outfile against the copy in the fenced code block.
     """
     example1_command = labeled.contents(label="directive-example-command")
     want = labeled.contents(label="directive-example-outfile")
-    simulator_status = verify.one_example(
+    simulator_status = example_tester(
         example1_command,
         want_file_name=None,
         pytest_options=["--doctest-modules", "-v"],
     )
     # Fenced code block in README.md is the same as the --outfile.
     got = simulator_status.outfile
-    verify.a_and_b_are_the_same(want, got)
+    checker(want, got)
     assert simulator_status.pytest_exit_code == 0
 
 
-def test_raw_example1_md():
+def test_ci_example():
+    """The bash lines in README are also in workflows/install.yml.
+
+    The fenced code block in README.md uses a different filename than
+    install.yml.  We need to replace README.md with project.md.
+    We need to replace test_readme.py with test_project.py.
+    """
+
+    # The goal of this test is fail if either install.yml
+    # or the fenced code block example is changed in one, but not
+    # both places.
+    fcb = labeled.contents(label="ci-example")
+    fcb_lower_case = fcb.lower()
+    fcb_lines = fcb_lower_case.splitlines()
+    edited_lines_in_fcb = [line.replace("readme", "project") for line in fcb_lines]
+    whole_file = Path(".github/workflows/install.yml").read_text(encoding="utf-8")
+    lines_in_file = whole_file.splitlines()
+    stripped_lines_in_file = [line.strip() for line in lines_in_file]
+    assert len(edited_lines_in_fcb) == 3
+    for line in edited_lines_in_fcb:
+        assert line in stripped_lines_in_file, "line must be somewhere in file"
+
+
+def test_actions_usage_md(checker):
+    """Cut and paste from ci.yml to actions_usage.md is the same."""
+    blocks = phmdoctest.tool.fenced_code_blocks("doc/actions_usage.md")
+    got = blocks[0]
+    whole_file = Path(".github/workflows/ci.yml").read_text(encoding="utf-8")
+    m = re.search(
+        pattern=r"(jobs:.*\n)\n  coverage:", string=whole_file, flags=re.DOTALL
+    )
+    want = m.group(1)
+    checker(a=want, b=got)
+
+
+def test_raw_example1_md(checker):
     """README raw markdown is same as file doc/example1.md."""
     want = labeled.contents(label="example1-raw")
-    with open("doc/example1.md", "r", encoding="utf-8") as fp:
-        got = fp.read()
-        verify.a_and_b_are_the_same(want, got)
+    got = Path("doc/example1.md").read_text(encoding="utf-8")
+    checker(want, got)
 
 
-def test_example1():
+def test_example1(example_tester, checker):
     """Make sure generated --outfile is as expected; Run pytest.
 
     Check the copy of test_example1.py in the fenced code block.
@@ -62,17 +108,16 @@ def test_example1():
     # The helper checks the generated --outfile against the disk file.
     example1_command = labeled.contents(label="example1-command")
     want = labeled.contents(label="example1-outfile")
-    _ = verify.one_example(
+    _ = example_tester(
         example1_command, want_file_name="doc/test_example1.py", pytest_options=None
     )
     # Make sure the copy of test_example1.py in README.md
     # is the same as the disk file.
-    with open("doc/test_example1.py", "r", encoding="utf-8") as fp:
-        got = fp.read()
-        verify.a_and_b_are_the_same(want, got)
+    got = Path("doc/test_example1.py").read_text(encoding="utf-8")
+    checker(want, got)
 
     # Run again and call pytest to make sure the file works with pytest.
-    simulator_status = verify.one_example(
+    simulator_status = example_tester(
         example1_command,
         want_file_name=None,
         pytest_options=["--doctest-modules", "-v"],
@@ -80,15 +125,17 @@ def test_example1():
     assert simulator_status.pytest_exit_code == 0
 
 
-def test_report():
+def test_report(checker):
     """README report output is same as produced by the command."""
     report_command = labeled.contents(label="report-command")
     want = labeled.contents(label="example2-report")
     simulator_status = phmdoctest.simulator.run_and_pytest(
         report_command, pytest_options=None
     )
+    assert simulator_status.runner_status.exit_code == 0
+    assert simulator_status.pytest_exit_code is None
     got = simulator_status.runner_status.stdout
-    verify.a_and_b_are_the_same(want, got)
+    checker(want, got)
 
 
 def test_intro_to_directives():
@@ -110,20 +157,20 @@ def chooser_example_code():
     print(text)
 
 
-def test_fcb_chooser(capsys):
+def test_fcb_chooser(capsys, checker):
     """Check 3 parts of the label on any fenced code block example."""
     # 1. The .md shown in the fenced code block is the same
     #    as the file on disk.
     want = labeled.contents(label="my-markdown-file")
-    with open("doc/my_markdown_file.md", "r", encoding="utf-8") as fp:
-        got = fp.read()
-    verify.a_and_b_are_the_same(want, got)
+    got = Path("doc/my_markdown_file.md").read_text(encoding="utf-8")
+    checker(want, got)
 
     # 2. The Python code example in the fenced code block is the same as
     #    the body of the function chooser_example_code() above.
-    verify.example_code_checker(
+    example_code_checker(
         callable_function=chooser_example_code,
         example_string=labeled.contents(label="fetch-it"),
+        checker_function=checker,
     )
 
     # 3. The example output shown in the fenced code block is
@@ -134,18 +181,18 @@ def test_fcb_chooser(capsys):
     got3 = capsys.readouterr().out
     assert got3.endswith("\n\n"), "FCB newline + print() newline"
     got3 = got3[:-1]  # drop the newline that print() added.
-    verify.a_and_b_are_the_same(want3, got3)
+    checker(want3, got3)
 
 
-def test_setup_first_fcb():
+def test_setup_first_fcb(checker):
     """Make sure example setup fenced code block same as in the file."""
     want = labeled.contents(label="setup-md-first-block")
     blocks = phmdoctest.tool.fenced_code_blocks("doc/setup.md")
     got = blocks[0]
-    verify.a_and_b_are_the_same(want, got)
+    checker(want, got)
 
 
-def test_directive1_example():
+def test_directive1_example(example_tester, checker):
     """Make sure generated --outfile and --report are as expected."""
 
     # Note that the report_command is hard coded here.
@@ -153,20 +200,18 @@ def test_directive1_example():
     report_command = "phmdoctest doc/directive1.md --report"
 
     directive_command = labeled.contents(label="directive-1-outfile")
-    _ = verify.one_example(
+    _ = example_tester(
         directive_command, want_file_name="doc/test_directive1.py", pytest_options=None
     )
-
-    with open("doc/directive1_report.txt") as f:
-        want = f.read()
-    simulator_status = verify.one_example(
+    want = Path("doc/directive1_report.txt").read_text(encoding="utf-8")
+    simulator_status = example_tester(
         report_command, want_file_name=None, pytest_options=None
     )
     got = simulator_status.runner_status.stdout
-    verify.a_and_b_are_the_same(want, got)
+    checker(want, got)
 
 
-def test_directive2_example():
+def test_directive2_example(example_tester, checker):
     """Make sure generated --outfile and --report are as expected."""
 
     # Note that the report_command is hard coded here.
@@ -174,20 +219,18 @@ def test_directive2_example():
     report_command = "phmdoctest doc/directive2.md --report"
 
     directive_command = labeled.contents(label="directive-2-outfile")
-    _ = verify.one_example(
+    _ = example_tester(
         directive_command, want_file_name="doc/test_directive2.py", pytest_options=None
     )
-
-    with open("doc/directive2_report.txt") as f:
-        want = f.read()
-    simulator_status = verify.one_example(
+    want = Path("doc/directive2_report.txt").read_text(encoding="utf-8")
+    simulator_status = example_tester(
         report_command, want_file_name=None, pytest_options=None
     )
     got = simulator_status.runner_status.stdout
-    verify.a_and_b_are_the_same(want, got)
+    checker(want, got)
 
 
-def test_directive3_example():
+def test_directive3_example(example_tester, checker):
     """Make sure generated --outfile and --report are as expected."""
 
     # Note that the report_command is hard coded here.
@@ -195,115 +238,108 @@ def test_directive3_example():
     report_command = "phmdoctest doc/directive3.md --report"
 
     directive_command = labeled.contents(label="directive-3-outfile")
-    _ = verify.one_example(
+    _ = example_tester(
         directive_command, want_file_name="doc/test_directive3.py", pytest_options=None
     )
-
-    with open("doc/directive3_report.txt") as f:
-        want = f.read()
-    simulator_status = verify.one_example(
+    want = Path("doc/directive3_report.txt").read_text(encoding="utf-8")
+    simulator_status = example_tester(
         report_command, want_file_name=None, pytest_options=None
     )
     got = simulator_status.runner_status.stdout
-    verify.a_and_b_are_the_same(want, got)
+    checker(want, got)
 
 
-def test_inline_pass():
+def test_inline_pass(checker):
     """Show the result block is produced by the code block."""
     code = labeled.contents(label="pass-code")
     assert code
     want, num_commented_out = phmdoctest.inline.apply_inline_commands(code)
     got = labeled.contents(label="pass-result")
     assert num_commented_out == 1
-    verify.a_and_b_are_the_same(want, got)
+    checker(want, got)
 
 
-def test_inline_omit():
+def test_inline_omit(checker):
     """Show the result block is produced by the code block."""
     code = labeled.contents(label="omit-code")
     assert code
     want, num_commented_out = phmdoctest.inline.apply_inline_commands(code)
     got = labeled.contents(label="omit-result")
     assert num_commented_out == 2
-    verify.a_and_b_are_the_same(want, got)
+    checker(want, got)
 
 
-def test_inline_example():
+def test_inline_example(example_tester):
     """Make sure generated --outfile is as the same as on disk."""
     directive_command = labeled.contents(label="inline-outfile")
-    _ = verify.one_example(
+    _ = example_tester(
         directive_command,
         want_file_name="doc/test_inline_example.py",
         pytest_options=None,
     )
 
 
-def test_skip_example():
+def test_skip_example(example_tester, checker):
     """Make sure generated --outfile and --report are as expected."""
     skip_command = labeled.contents(label="skip-command")
     want = labeled.contents(label="skip-report")
     short_form_command = labeled.contents(label="short-skip-command")
-    simulator_status = verify.one_example(
+    simulator_status = example_tester(
         skip_command, want_file_name="doc/test_example2.py", pytest_options=None
     )
     got1 = simulator_status.runner_status.stdout
-    verify.a_and_b_are_the_same(want, got1)
+    checker(want, got1)
 
     # test the first -s form of the --skip
-    simulator_status = verify.one_example(
+    simulator_status = example_tester(
         short_form_command, want_file_name="doc/test_example2.py", pytest_options=None
     )
     got2 = simulator_status.runner_status.stdout
-    verify.a_and_b_are_the_same(want, got2)
+    checker(want, got2)
 
 
-def test_setup_report_example():
+def test_setup_report_example(example_tester, checker):
     """Make sure report in README is correct."""
     command = labeled.contents(label="setup-command-report")
     want = labeled.contents(label="setup-report")
-    simulator_status = verify.one_example(
-        command, want_file_name=None, pytest_options=None
-    )
+    simulator_status = example_tester(command, want_file_name=None, pytest_options=None)
     got1 = simulator_status.runner_status.stdout
-    verify.a_and_b_are_the_same(want, got1)
+    checker(want, got1)
 
 
-def test_setup():
+def test_setup(example_tester):
     """Make sure --setup --outfile is correct."""
     command = labeled.contents(label="setup-command-outfile")
-    _ = verify.one_example(
-        command, want_file_name="doc/test_setup.py", pytest_options=None
-    )
+    _ = example_tester(command, want_file_name="doc/test_setup.py", pytest_options=None)
 
 
-def test_setup_doctest():
+def test_setup_doctest(example_tester):
     """Make sure --setup-doctest --outfile is correct."""
     command = labeled.contents(label="setup-doctest-outfile")
-    _ = verify.one_example(
+    _ = example_tester(
         command, want_file_name="doc/test_setup_doctest.py", pytest_options=None
     )
 
 
-def test_outfile_to_stdout():
+def test_outfile_to_stdout(example_tester, checker):
     """Make sure generated --outfile and --report are as expected."""
     outfile_command1 = labeled.contents(label="outfile-dash1")
     outfile_command2 = labeled.contents(label="outfile-dash2")
-    simulator_status = verify.one_example(
+    simulator_status = example_tester(
         outfile_command1, want_file_name=None, pytest_options=None
     )
-    with open("doc/test_example2.py", "r", encoding="utf-8") as fp:
-        want = fp.read()
+    want = Path("doc/test_example2.py").read_text(encoding="utf-8")
     got1 = simulator_status.runner_status.stdout
-    verify.a_and_b_are_the_same(want, got1)
+    checker(want, got1)
 
-    simulator_status = verify.one_example(
+    simulator_status = example_tester(
         outfile_command2, want_file_name=None, pytest_options=None
     )
     got2 = simulator_status.runner_status.stdout
-    verify.a_and_b_are_the_same(want, got2)
+    checker(want, got2)
 
 
-def test_usage():
+def test_usage(checker):
     """Example usage near the bottom."""
     # Note- There may be differences in whitespace between
     #       the README.md fenced code block and the
@@ -317,37 +353,62 @@ def test_usage():
     simulator_status = phmdoctest.simulator.run_and_pytest(
         "phmdoctest --help", pytest_options=None
     )
+    assert simulator_status.runner_status.exit_code == 0
+    assert simulator_status.pytest_exit_code is None
     want1 = labeled.contents(label="usage")
     want2 = re.sub(r"\s+", " ", want1)
 
     got1 = simulator_status.runner_status.stdout
     got2 = got1.replace("entry-point", "phmdoctest", 1)
     got3 = re.sub(r"\s+", " ", got2)
-    verify.a_and_b_are_the_same(want2, got3)
+    checker(want2, got3)
 
 
-def test_yaml():
-    """Show the 2 lines are in both Markdown example and .travis.yml."""
-    # Note the lines are indented 8 spaces in both files, so they must have
-    # the same indent here.
-    expected = """
-        - mkdir tests/tmp
-        - phmdoctest project.md --report --outfile tests/tmp/test_project.py
-        """
-    markdown_example_text = labeled.contents(label="yaml")
-    with open(".travis.yml", "r", encoding="utf-8") as f:
-        travis_text = f.read()
-    assert expected in travis_text
-    assert expected in markdown_example_text
+def test_testfile(checker):
+    """Assure the guts of the callable_function are same as in Markdown."""
+    example_code_checker(
+        callable_function=test_testfile_example_code,
+        example_string=labeled.contents(label="main-testfile"),
+        checker_function=checker,
+    )
 
 
-# Developers: Changes here must be mirrored in a Markdown FCB in README.md.
 # Runnable version of example code in README.md.
-# The guts of this function are an exact copy of example in README.md.
-def simulator_example_code():
+# The guts of this function are an exact copy of the example
+# in README.md with label main-testfile.
+# Note that this file is collected and run by pytest.
+# Show main.testfile() usage. Verify correct file is generated.
+def test_testfile_example_code():
+    from pathlib import Path
+    import phmdoctest.main
+
+    generated_testfile = phmdoctest.main.testfile(
+        "doc/setup.md",
+        setup="FIRST",
+        teardown="LAST",
+    )
+    expected = Path("doc/test_setup.py").read_text(encoding="utf-8")
+    assert expected == generated_testfile
+
+
+def test_simulator(checker):
+    """Assure the guts of callable_function are same as in Markdown."""
+    example_code_checker(
+        callable_function=test_simulator_example_code,
+        example_string=labeled.contents(label="simulator"),
+        checker_function=checker,
+    )
+
+
+# Runnable version of example code in README.md.
+# The guts of this function are an exact copy of the example
+# in README.md with label simulator.
+# Note that this file is collected and run by pytest.
+# Show simulator.run_and_pytest() usage.
+def test_simulator_example_code():
     import phmdoctest.simulator
 
-    command = "phmdoctest doc/example1.md --report --outfile test_me.py"
+    command = "phmdoctest doc/example1.md --report --outfile temporary.py"
     simulator_status = phmdoctest.simulator.run_and_pytest(
         well_formed_command=command, pytest_options=["--doctest-modules", "-v"]
     )
@@ -355,22 +416,73 @@ def simulator_example_code():
     assert simulator_status.pytest_exit_code == 0
 
 
-def test_simulator():
-    """Assure the guts of the function are same as in Markdown."""
-    verify.example_code_checker(
-        callable_function=simulator_example_code,
-        example_string=labeled.contents(label="simulator"),
-    )
-
-    # also make sure the code runs with no assertions
-    simulator_example_code()
-
-
 def test_quick_links():
     """Make sure the README.md quick links are up to date."""
     filename = "README.md"
+    readme = Path("README.md").read_text(encoding="utf-8")
+    github_links = make_quick_links(filename)
+    # There must be at least one blank line after the last link.
+    assert github_links + "\n\n" in readme
+
+
+def remove_fenced_code_blocks(lines, fence="```"):
+    """Return lines not starting with fence or between fences."""
+    skipping = False
+    for line in lines:
+        if skipping and line.startswith(fence):
+            skipping = False
+            continue
+
+        if not skipping and line.startswith(fence):
+            skipping = True
+            continue
+
+        if not skipping:
+            yield line
+
+
+def make_label(title):
+    """Make the [] part of a link.  Rewrite if last word is 'option'."""
+    # Special handling if the last word of the title is option.
+    # The word option indicates the preceding word should have the
+    # prefix '--' in the link label since it is a command line option.
+    # Titles with '--' seem to break on GitHub pages.
+    parts = title.split()
+    if parts[-1] == "option":
+        parts.pop(-1)
+        parts[-1] = "--" + parts[-1]
+    title = " ".join(parts)
+    return "[" + title + "]"
+
+
+def make_quick_links(filename):
+    """Generate links for a quick links section."""
+    header_level = "## "  # note trailing space
     with open(filename, "r", encoding="utf-8") as f:
-        readme = f.read()
-        github_links = quick_links.make_quick_links(filename, style="github")
-        # There must be at least one blank line after the last link.
-        assert github_links + "\n\n" in readme
+        lines = f.readlines()
+    lines = [line.rstrip() for line in lines]  # lose newlines
+    # README.md has fenced code blocks that enclose other
+    # fenced code blocks.  The outer blocks use ~~~ as the fence.
+    # Remove the outer fenced code blocks first.
+    lines = remove_fenced_code_blocks(lines, "~~~")
+    lines = remove_fenced_code_blocks(lines)
+    links = []
+    for line in lines:
+        if line.startswith(header_level):
+            assert "--" not in line, "Please rewrite to avert breakage on Pages."
+            title = line.replace(header_level, "")
+            label = make_label(title)
+            link = title.lower()
+            link = link.replace(" ", "-")
+            link = "(#" + link + ")"
+            links.append(label + link)
+    return " |\n".join(links)
+
+
+if __name__ == "__main__":
+    # To generate quick links, from repository root run: python tests/test_readme.py
+    text = make_quick_links("README.md")
+    print(text)
+    print()
+    num_links = text.count("\n") + 1
+    print("created {} links, {} characters".format(num_links, len(text)))
